@@ -9,6 +9,7 @@ use crate::{
 use anyhow::Result;
 use bytes::Bytes;
 
+#[derive(Debug, Copy, Clone)]
 pub struct OpusPayloader;
 
 impl Payloader for OpusPayloader {
@@ -19,10 +20,14 @@ impl Payloader for OpusPayloader {
 
         Ok(vec![payload.clone()])
     }
+
+    fn clone_to(&self) -> Box<dyn Payloader + Send + Sync> {
+        Box::new(*self)
+    }
 }
 
 /// OpusPacket represents the Opus header that is stored in the payload of an RTP Packet
-#[derive(Debug, Default)]
+#[derive(PartialEq, Debug, Default, Clone)]
 pub struct OpusPacket {
     pub payload: Bytes,
 }
